@@ -3,12 +3,12 @@ package AnyEvent::Finger;
 use strict;
 use warnings;
 use v5.10;
-BEGIN { our @ISA; push @ISA, 'Exporter' }
 
+our @ISA = qw( Exporter );
 our @EXPORT_OK = qw( finger_client finger_server );
 
 # ABSTRACT: Simple asynchronous finger client and server
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 
 sub finger_client
@@ -48,7 +48,7 @@ AnyEvent::Finger - Simple asynchronous finger client and server
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
